# Summary of 1 files

## UnknownSegmentationFaultWithTraceback

```
#6  0xXXXXXXXXXXXXXXXXXX in bool Relations::TraitsHelpers::LessByFrom<Relations::KeyedObjectTypeTraits<LHCb::Particle>::Less>::operator()<Relations::Entry_<LHCb::Particle, std::map<std::__cxx11::basic_string<char, std::char_traits<char>, std::allocator<char> >, LHCb::detail::TisTosResult_t, std::less<std::__cxx11::basic_string<char, std::char_traits<char>, std::allocator<char> > >, std::allocator<std::pair<std::__cxx11::basic_string<char, std::char_traits<char>, std::allocator<char> > const, LHCb::detail::TisTosResult_t> > > > >(Relations::Entry_<LHCb::Particle, std::map<std::__cxx11::basic_string<char, std::char_traits<char>, std::allocator<char> >, LHCb::detail::TisTosResult_t, std::less<std::__cxx11::basic_string<char, std::char_traits<char>, std::allocator<char> > >, std::allocator<std::pair<std::__cxx11::basic_string<char, std::char_traits<char>, std::allocator<char> > const, LHCb::detail::TisTosResult_t> > > > const&, Relations::Entry_<LHCb::Particle, std::map<std::__cxx11::basic_string<char, std::char_traits<char>, std::allocator<char> >, LHCb::detail::TisTosResult_t, std::less<std::__cxx11::basic_string<char, std::char_traits<char>, std::allocator<char> > >, std::allocator<std::pair<std::__cxx11::basic_string<char, std::char_traits<char>, std::allocator<char> > const, LHCb::detail::TisTosResult_t> > > > const&) const () from /cvmfs/lhcb.cern.ch/lib/lhcb/REC/REC_v36r12/InstallArea/x86_64_v2-el9-clang16-opt/lib/libTisTosTobbing.so
#7  0xXXXXXXXXXXXXXXXXXX in std::pair<__gnu_cxx::__normal_iterator<Relations::Entry_<LHCb::Particle, std::map<std::__cxx11::basic_string<char, std::char_traits<char>, std::allocator<char> >, LHCb::detail::TisTosResult_t, std::less<std::__cxx11::basic_string<char, std::char_traits<char>, std::allocator<char> > >, std::allocator<std::pair<std::__cxx11::basic_string<char, std::char_traits<char>, std::allocator<char> > const, LHCb::detail::TisTosResult_t> > > > const*, std::vector<Relations::Entry_<LHCb::Particle, std::map<std::__cxx11::basic_string<char, std::char_traits<char>, std::allocator<char> >, LHCb::detail::TisTosResult_t, std::less<std::__cxx11::basic_string<char, std::char_traits<char>, std::allocator<char> > >, std::allocator<std::pair<std::__cxx11::basic_string<char, std::char_traits<char>, std::allocator<char> > const, LHCb::detail::TisTosResult_t> > > >, std::allocator<Relations::Entry_<LHCb::Particle, std::map<std::__cxx11::basic_string<char, std::char_traits<char>, std::allocator<char> >, LHCb::detail::TisTosResult_t, std::less<std::__cxx11::basic_string<char, std::char_traits<char>, std::allocator<char> > >, std::allocator<std::pair<std::__cxx11::basic_string<char, std::char_traits<char>, std::allocator<char> > const, LHCb::detail::TisTosResult_t> > > > > > >, __gnu_cxx::__normal_iterator<Relations::Entry_<LHCb::Particle, std::map<std::__cxx11::basic_string<char, std::char_traits<char>, std::allocator<char> >, LHCb::detail::TisTosResult_t, std::less<std::__cxx11::basic_string<char, std::char_traits<char>, std::allocator<char> > >, std::allocator<std::pair<std::__cxx11::basic_string<char, std::char_traits<char>, std::allocator<char> > const, LHCb::detail::TisTosResult_t> > > > const*, std::vector<Relations::Entry_<LHCb::Particle, std::map<std::__cxx11::basic_string<char, std::char_traits<char>, std::allocator<char> >, LHCb::detail::TisTosResult_t, std::less<std::__cxx11::basic_string<char, std::char_traits<char>, std::allocator<char> > >, std::allocator<std::pair<std::__cxx11::basic_string<char, std::char_traits<char>, std::allocator<char> > const, LHCb::detail::TisTosResult_t> > > >, std::allocator<Relations::Entry_<LHCb::Particle, std::map<std::__cxx11::basic_string<char, std::char_traits<char>, std::allocator<char> >, LHCb::detail::TisTosResult_t, std::less<std::__cxx11::basic_string<char, std::char_traits<char>, std::allocator<char> > >, std::allocator<std::pair<std::__cxx11::basic_string<char, std::char_traits<char>, std::allocator<char> > const, LHCb::detail::TisTosResult_t> > > > > > > > std::__equal_range<__gnu_cxx::__normal_iterator<Relations::Entry_<LHCb::Particle, std::map<std::__cxx11::basic_string<char, std::char_traits<char>, std::allocator<char> >, LHCb::detail::TisTosResult_t, std::less<std::__cxx11::basic_string<char, std::char_traits<char>, std::allocator<char> > >, std::allocator<std::pair<std::__cxx11::basic_string<char, std::char_traits<char>, std::allocator<char> > const, LHCb::detail::TisTosResult_t> > > > const*, std::vector<Relations::Entry_<LHCb::Particle, std::map<std::__cxx11::basic_string<char, std::char_traits<char>, std::allocator<char> >, LHCb::detail::TisTosResult_t, std::less<std::__cxx11::basic_string<char, std::char_traits<char>, std::allocator<char> > >, std::allocator<std::pair<std::__cxx11::basic_string<char, std::char_traits<char>, std::allocator<char> > const, LHCb::detail::TisTosResult_t> > > >, std::allocator<Relations::Entry_<LHCb::Particle, std::map<std::__cxx11::basic_string<char, std::char_traits<char>, std::allocator<char> >, LHCb::detail::TisTosResult_t, std::less<std::__cxx11::basic_string<char, std::char_traits<char>, std::allocator<char> > >, std::allocator<std::pair<std::__cxx11::basic_string<char, std::char_traits<char>, std::allocator<char> > const, LHCb::detail::TisTosResult_t> > > > > > >, Relations::Entry_<LHCb::Particle, std::map<std::__cxx11::basic_string<char, std::char_traits<char>, std::allocator<char> >, LHCb::detail::TisTosResult_t, std::less<std::__cxx11::basic_string<char, std::char_traits<char>, std::allocator<char> > >, std::allocator<std::pair<std::__cxx11::basic_string<char, std::char_traits<char>, std::allocator<char> > const, LHCb::detail::TisTosResult_t> > > >, __gnu_cxx::__ops::_Iter_comp_val<Relations::TraitsHelpers::LessByFrom<Relations::KeyedObjectTypeTraits<LHCb::Particle>::Less> >, __gnu_cxx::__ops::_Val_comp_iter<Relations::TraitsHelpers::LessByFrom<Relations::KeyedObjectTypeTraits<LHCb::Particle>::Less> > >(__gnu_cxx::__normal_iterator<Relations::Entry_<LHCb::Particle, std::map<std::__cxx11::basic_string<char, std::char_traits<char>, std::allocator<char> >, LHCb::detail::TisTosResult_t, std::less<std::__cxx11::basic_string<char, std::char_traits<char>, std::allocator<char> > >, std::allocator<std::pair<std::__cxx11::basic_string<char, std::char_traits<char>, std::allocator<char> > const, LHCb::detail::TisTosResult_t> > > > const*, std::vector<Relations::Entry_<LHCb::Particle, std::map<std::__cxx11::basic_string<char, std::char_traits<char>, std::allocator<char> >, LHCb::detail::TisTosResult_t, std::less<std::__cxx11::basic_string<char, std::char_traits<char>, std::allocator<char> > >, std::allocator<std::pair<std::__cxx11::basic_string<char, std::char_traits<char>, std::allocator<char> > const, LHCb::detail::TisTosResult_t> > > >, std::allocator<Relations::Entry_<LHCb::Particle, std::map<std::__cxx11::basic_string<char, std::char_traits<char>, std::allocator<char> >, LHCb::detail::TisTosResult_t, std::less<std::__cxx11::basic_string<char, std::char_traits<char>, std::allocator<char> > >, std::allocator<std::pair<std::__cxx11::basic_string<char, std::char_traits<char>, std::allocator<char> > const, LHCb::detail::TisTosResult_t> > > > > > >, __gnu_cxx::__normal_iterator<Relations::Entry_<LHCb::Particle, std::map<std::__cxx11::basic_string<char, std::char_traits<char>, std::allocator<char> >, LHCb::detail::TisTosResult_t, std::less<std::__cxx11::basic_string<char, std::char_traits<char>, std::allocator<char> > >, std::allocator<std::pair<std::__cxx11::basic_string<char, std::char_traits<char>, std::allocator<char> > const, LHCb::detail::TisTosResult_t> > > > const*, std::vector<Relations::Entry_<LHCb::Particle, std::map<std::__cxx11::basic_string<char, std::char_traits<char>, std::allocator<char> >, LHCb::detail::TisTosResult_t, std::less<std::__cxx11::basic_string<char, std::char_traits<char>, std::allocator<char> > >, std::allocator<std::pair<std::__cxx11::basic_string<char, std::char_traits<char>, std::allocator<char> > const, LHCb::detail::TisTosResult_t> > > >, std::allocator<Relations::Entry_<LHCb::Particle, std::map<std::__cxx11::basic_string<char, std::char_traits<char>, std::allocator<char> >, LHCb::detail::TisTosResult_t, std::less<std::__cxx11::basic_string<char, std::char_traits<char>, std::allocator<char> > >, std::allocator<std::pair<std::__cxx11::basic_string<char, std::char_traits<char>, std::allocator<char> > const, LHCb::detail::TisTosResult_t> > > > > > >, Relations::Entry_<LHCb::Particle, std::map<std::__cxx11::basic_string<char, std::char_traits<char>, std::allocator<char> >, LHCb::detail::TisTosResult_t, std::less<std::__cxx11::basic_string<char, std::char_traits<char>, std::allocator<char> > >, std::allocator<std::pair<std::__cxx11::basic_string<char, std::char_traits<char>, std::allocator<char> > const, LHCb::detail::TisTosResult_t> > > > const&, __gnu_cxx::__ops::_Iter_comp_val<Relations::TraitsHelpers::LessByFrom<Relations::KeyedObjectTypeTraits<LHCb::Particle>::Less> >, __gnu_cxx::__ops::_Val_comp_iter<Relations::TraitsHelpers::LessByFrom<Relations::KeyedObjectTypeTraits<LHCb::Particle>::Less> >) () from /cvmfs/lhcb.cern.ch/lib/lhcb/REC/REC_v36r12/InstallArea/x86_64_v2-el9-clang16-opt/lib/libTisTosTobbing.so
#8  0xXXXXXXXXXXXXXXXXXX in LHCb::Relation1D<LHCb::Particle, std::map<std::__cxx11::basic_string<char, std::char_traits<char>, std::allocator<char> >, LHCb::detail::TisTosResult_t, std::less<std::__cxx11::basic_string<char, std::char_traits<char>, std::allocator<char> > >, std::allocator<std::pair<std::__cxx11::basic_string<char, std::char_traits<char>, std::allocator<char> > const, LHCb::detail::TisTosResult_t> > > >::relations(LHCb::Particle const*) const () from /cvmfs/lhcb.cern.ch/lib/lhcb/REC/REC_v36r12/InstallArea/x86_64_v2-el9-clang16-opt/lib/libTisTosTobbing.so
#9  0xXXXXXXXXXXXXXXXXXX in decltype(auto) Functors::detail::prepare_chain::{lambda((auto:1&&)...)#1}::operator()<Functors::detail::prepared<Functors::Functional::ValueOr<bool> >, Functors::detail::prepared<Functors::detail::IsTrigCategory<(Functors::detail::TriggerCategories)0> >, Functors::detail::prepared<Functors::Functional::ValueFromDict<std::__cxx11::basic_string<char, std::char_traits<char>, std::allocator<char> > > >, Functors::detail::prepared<Functors::Common::To>, Functors::detail::prepared<Functors::Functional::Front>, Functors::detail::prepared<Functors::detail::ComposedFunctor<Functors::detail::composition::bind, Functors::Function, Functors::Function, Functors::Common::Relations, Functors::Common::TES<LHCb::Relation1D<LHCb::Particle, std::map<std::__cxx11::basic_string<char, std::char_traits<char>, std::allocator<char> >, LHCb::detail::TisTosResult_t, std::less<std::__cxx11::basic_string<char, std::char_traits<char>, std::allocator<char> > >, std::allocator<std::pair<std::__cxx11::basic_string<char, std::char_traits<char>, std::allocator<char> > const, LHCb::detail::TisTosResult_t> > > > >, Functors::Common::ForwardArgs<-1> > > >(Functors::detail::prepared<Functors::Functional::ValueOr<bool> >&&, Functors::detail::prepared<Functors::detail::IsTrigCategory<(Functors::detail::TriggerCategories)0> >&&, Functors::detail::prepared<Functors::Functional::ValueFromDict<std::__cxx11::basic_string<char, std::char_traits<char>, std::allocator<char> > > >&&, Functors::detail::prepared<Functors::Common::To>&&, Functors::detail::prepared<Functors::Functional::Front>&&, Functors::detail::prepared<Functors::detail::ComposedFunctor<Functors::detail::composition::bind, Functors::Function, Functors::Function, Functors::Common::Relations, Functors::Common::TES<LHCb::Relation1D<LHCb::Particle, std::map<std::__cxx11::basic_string<char, std::char_traits<char>, std::allocator<char> >, LHCb::detail::TisTosResult_t, std::less<std::__cxx11::basic_string<char, std::char_traits<char>, std::allocator<char> > >, std::allocator<std::pair<std::__cxx11::basic_string<char, std::char_traits<char>, std::allocator<char> > const, LHCb::detail::TisTosResult_t> > > > >, Functors::Common::ForwardArgs<-1> > >&&) const::{lambda(auto:1, (auto:2&&)...)#1}::operator()<bool, LHCb::Particle const&>(bool, LHCb::Particle const&) const::{lambda((auto:1 const&)...)#1}::operator()<Functors::detail::prepared<Functors::Functional::ValueOr<bool> >, Functors::detail::prepared<Functors::detail::IsTrigCategory<(Functors::detail::TriggerCategories)0> >, Functors::detail::prepared<Functors::Functional::ValueFromDict<std::__cxx11::basic_string<char, std::char_traits<char>, std::allocator<char> > > >, Functors::detail::prepared<Functors::Common::To>, Functors::detail::prepared<Functors::Functional::Front>, Functors::detail::prepared<Functors::detail::ComposedFunctor<Functors::detail::composition::bind, Functors::Function, Functors::Function, Functors::Common::Relations, Functors::Common::TES<LHCb::Relation1D<LHCb::Particle, std::map<std::__cxx11::basic_string<char, std::char_traits<char>, std::allocator<char> >, LHCb::detail::TisTosResult_t, std::less<std::__cxx11::basic_string<char, std::char_traits<char>, std::allocator<char> > >, std::allocator<std::pair<std::__cxx11::basic_string<char, std::char_traits<char>, std::allocator<char> > const, LHCb::detail::TisTosResult_t> > > > >, Functors::Common::ForwardArgs<-1> > > >(Functors::detail::prepared<Functors::Functional::ValueOr<bool> > const&, Functors::detail::prepared<Functors::detail::IsTrigCategory<(Functors::detail::TriggerCategories)0> > const&, Functors::detail::prepared<Functors::Functional::ValueFromDict<std::__cxx11::basic_string<char, std::char_traits<char>, std::allocator<char> > > > const&, Functors::detail::prepared<Functors::Common::To> const&, Functors::detail::prepared<Functors::Functional::Front> const&, Functors::detail::prepared<Functors::detail::ComposedFunctor<Functors::detail::composition::bind, Functors::Function, Functors::Function, Functors::Common::Relations, Functors::Common::TES<LHCb::Relation1D<LHCb::Particle, std::map<std::__cxx11::basic_string<char, std::char_traits<char>, std::allocator<char> >, LHCb::detail::TisTosResult_t, std::less<std::__cxx11::basic_string<char, std::char_traits<char>, std::allocator<char> > >, std::allocator<std::pair<std::__cxx11::basic_string<char, std::char_traits<char>, std::allocator<char> > const, LHCb::detail::TisTosResult_t> > > > >, Functors::Common::ForwardArgs<-1> > > const&) () from /tmp/FunctorJitLib_0x52b3011f13317357_0xXXXXXXXXXXXXXXXXXX.so
#10 0xXXXXXXXXXXXXXXXXXX in Functors::PreparedFunctor<std::any (LHCb::Particle const&)>::VTable::create<Functors::detail::prepared<Functors::detail::ComposedFunctor<Functors::detail::composition::chain, Functors::Function, Functors::Function, Functors::Functional::ValueOr<bool>, Functors::detail::IsTrigCategory<(Functors::detail::TriggerCategories)0>, Functors::Functional::ValueFromDict<std::__cxx11::basic_string<char, std::char_traits<char>, std::allocator<char> > >, Functors::Common::To, Functors::Functional::Front, Functors::detail::ComposedFunctor<Functors::detail::composition::bind, Functors::Function, Functors::Function, Functors::Common::Relations, Functors::Common::TES<LHCb::Relation1D<LHCb::Particle, std::map<std::__cxx11::basic_string<char, std::char_traits<char>, std::allocator<char> >, LHCb::detail::TisTosResult_t, std::less<std::__cxx11::basic_string<char, std::char_traits<char>, std::allocator<char> > >, std::allocator<std::pair<std::__cxx11::basic_string<char, std::char_traits<char>, std::allocator<char> > const, LHCb::detail::TisTosResult_t> > > > >, Functors::Common::ForwardArgs<-1> > > > >()::{lambda(void const*, LHCb::Particle const&)#1}::__invoke(void const*, LHCb::Particle const&) () from /tmp/FunctorJitLib_0x52b3011f13317357_0xXXXXXXXXXXXXXXXXXX.so
#11 0xXXXXXXXXXXXXXXXXXX in FunTupleBase<Gaudi::NamedRange_<std::vector<LHCb::Particle const*, std::allocator<LHCb::Particle const*> >, __gnu_cxx::__normal_iterator<LHCb::Particle const* const*, std::vector<LHCb::Particle const*, std::allocator<LHCb::Particle const*> > > > >::get_thor_output(LHCb::Particle const&, unsigned int const&, unsigned int const&) const () from /cvmfs/lhcb.cern.ch/lib/lhcb/DAVINCI/DAVINCI_v64r9/InstallArea/x86_64_v2-el9-clang16-opt/lib/libFunTuple.so
#12 0xXXXXXXXXXXXXXXXXXX in FunTupleBase<Gaudi::NamedRange_<std::vector<LHCb::Particle const*, std::allocator<LHCb::Particle const*> >, __gnu_cxx::__normal_iterator<LHCb::Particle const* const*, std::vector<LHCb::Particle const*, std::allocator<LHCb::Particle const*> > > > >::fill_thor_func_output(LHCb::Particle const&, unsigned int const&, Tuples::Tuple const&) const () from /cvmfs/lhcb.cern.ch/lib/lhcb/DAVINCI/DAVINCI_v64r9/InstallArea/x86_64_v2-el9-clang16-opt/lib/libFunTuple.so
#13 0xXXXXXXXXXXXXXXXXXX in void FunTupleBase<Gaudi::NamedRange_<std::vector<LHCb::Particle const*, std::allocator<LHCb::Particle const*> >, __gnu_cxx::__normal_iterator<LHCb::Particle const* const*, std::vector<LHCb::Particle const*, std::allocator<LHCb::Particle const*> > > > >::write_tuple<Gaudi::NamedRange_<std::vector<LHCb::Particle const*, std::allocator<LHCb::Particle const*> >, __gnu_cxx::__normal_iterator<LHCb::Particle const* const*, std::vector<LHCb::Particle const*, std::allocator<LHCb::Particle const*> > > >, true>(std::vector<std::vector<LHCb::Particle const*, std::allocator<LHCb::Particle const*> >, std::allocator<std::vector<LHCb::Particle const*, std::allocator<LHCb::Particle const*> > > > const&) const () from /cvmfs/lhcb.cern.ch/lib/lhcb/DAVINCI/DAVINCI_v64r9/InstallArea/x86_64_v2-el9-clang16-opt/lib/libFunTuple.so
#14 0xXXXXXXXXXXXXXXXXXX in FunTupleBase<Gaudi::NamedRange_<std::vector<LHCb::Particle const*, std::allocator<LHCb::Particle const*> >, __gnu_cxx::__normal_iterator<LHCb::Particle const* const*, std::vector<LHCb::Particle const*, std::allocator<LHCb::Particle const*> > > > >::operator()(Gaudi::NamedRange_<std::vector<LHCb::Particle const*, std::allocator<LHCb::Particle const*> >, __gnu_cxx::__normal_iterator<LHCb::Particle const* const*, std::vector<LHCb::Particle const*, std::allocator<LHCb::Particle const*> > > > const&) const () from /cvmfs/lhcb.cern.ch/lib/lhcb/DAVINCI/DAVINCI_v64r9/InstallArea/x86_64_v2-el9-clang16-opt/lib/libFunTuple.so
#15 0xXXXXXXXXXXXXXXXXXX in Gaudi::Functional::details::Consumer<void (Gaudi::NamedRange_<std::vector<LHCb::Particle const*, std::allocator<LHCb::Particle const*> >, __gnu_cxx::__normal_iterator<LHCb::Particle const* const*, std::vector<LHCb::Particle const*, std::allocator<LHCb::Particle const*> > > > const&), Gaudi::Functional::Traits::BaseClass_t<LHCb::Det::LbDD4hep::ConditionAccessorHolder<GaudiTupleAlg> >, true>::execute() () from /cvmfs/lhcb.cern.ch/lib/lhcb/DAVINCI/DAVINCI_v64r9/InstallArea/x86_64_v2-el9-clang16-opt/lib/libFunTuple.so
#16 0xXXXXXXXXXXXXXXXXXX in Gaudi::Algorithm::sysExecute(EventContext const&) () from /cvmfs/lhcb.cern.ch/lib/lhcb/GAUDI/GAUDI_v38r1/InstallArea/x86_64_v2-el9-clang16-opt/lib/libGaudiKernel.so
#17 0xXXXXXXXXXXXXXXXXXX in GaudiAlgorithm::sysExecute(EventContext const&) () from /cvmfs/lhcb.cern.ch/lib/lhcb/LHCB/LHCB_v55r12/InstallArea/x86_64_v2-el9-clang16-opt/lib/libGaudiAlgLib.so
#18 0xXXXXXXXXXXXXXXXXXX in BasicNode::execute(gsl::span<LHCb::Interfaces::ISchedulerConfiguration::State::NodeState, 18446744073709551615ul>, gsl::span<LHCb::Interfaces::ISchedulerConfiguration::State::AlgState, 18446744073709551615ul>, std::deque<Gaudi::Accumulators::AveragingCounter<std::chrono::duration<unsigned long, std::ratio<1l, 1000000000l> >, (Gaudi::Accumulators::atomicity)1>, std::allocator<Gaudi::Accumulators::AveragingCounter<std::chrono::duration<unsigned long, std::ratio<1l, 1000000000l> >, (Gaudi::Accumulators::atomicity)1> > >&, EventContext&, IAlgExecStateSvc*, SmartIF<IProperty>&) const () from /cvmfs/lhcb.cern.ch/lib/lhcb/LHCB/LHCB_v55r12/InstallArea/x86_64_v2-el9-clang16-opt/lib/libHLTScheduler.so
#19 0xXXXXXXXXXXXXXXXXXX in tbb::detail::d1::enqueue_task<(anonymous namespace)::EventTask<HLTControlFlowMgr::push(EventContext&&)::$_0> >::execute(tbb::detail::d1::execution_data&) () from /cvmfs/lhcb.cern.ch/lib/lhcb/LHCB/LHCB_v55r12/InstallArea/x86_64_v2-el9-clang16-opt/lib/libHLTScheduler.so
#20 0xXXXXXXXXXXXXXXXXXX in tbb::detail::r1::arena::process(tbb::detail::r1::thread_data&) () from /cvmfs/lhcb.cern.ch/lib/lcg/releases/tbb/2021.10.0-2a247/x86_64-el9-clang16-opt/lib64/libtbb.so.12
#21 0xXXXXXXXXXXXXXXXXXX in tbb::detail::r1::market::process(rml::job&) () from /cvmfs/lhcb.cern.ch/lib/lcg/releases/tbb/2021.10.0-2a247/x86_64-el9-clang16-opt/lib64/libtbb.so.12
#22 0xXXXXXXXXXXXXXXXXXX in tbb::detail::r1::rml::private_worker::thread_routine(void*) () from /cvmfs/lhcb.cern.ch/lib/lcg/releases/tbb/2021.10.0-2a247/x86_64-el9-clang16-opt/lib64/libtbb.so.12
#23 0xXXXXXXXXXXXXXXXXXX in start_thread () from /lib64/libc.so.6
#24 0xXXXXXXXXXXXXXXXXXX in clone3 () from /lib64/libc.so.6


```

A segmentation fault occurred

| Transform | LFN | Job ID | Site | Peak Mem | Log URL(s) |
| --------- | --- | ------ | ---- | -------- | ---------- |
| `249402` | `LFN:/lhcb/LHCb/Collision24/QEE.DST/00231024/0027/00231024_00275162_1.qee.dst` | 980552996 | LCG.NCBJ.pl | 2.5 GiB | [here](https://lhcb-productions.web.cern.ch/logs/?lfn=%2Flhcb%2FLHCb%2FCollision24%2FLOG%2F00249402%2F0002&task_name=00026393) |
